@@ -45,6 +45,10 @@ use constant {
     TOP_LABEL_HEIGHT    => 2,
 };
 
+my $OURNAME = "sysv-rc-conf";
+my $VERSION = "1.2.1";
+my $called_as_chkconfig = $0 =~ /chkconfig$/;
+
 # Runlevel patterns: [ state regex, inverse video, colour, summary ]
 my $rl_patterns = [
     [qr(^01111002),           0, "green",   "Multiuser"],
@@ -69,10 +73,6 @@ my $rl_patterns = [
     [qr(.*),                  0, "",        "Custom"]
 ];
 
-my $OURNAME = "sysv-rc-conf";
-my $VERSION = "1.2.0";
-my $called_as_chkconfig = $0 =~ /chkconfig$/;
-
 my %def_alt_init_handler = (
     is_managed => sub { return 0; },
 );
@@ -126,21 +126,28 @@ my %opts = (
     insserv     => 0,
     interpret   => 1,
     defdiff     => 1,
-    pictograms  => ($ENV{LANG} =~ /\.UTF-8$/ ? 1 : 0),
+    pictograms  => 0,
+    warninit    => 1,
 );
 my @mutually_exclusive_options = qw(chkcfg_list chkcfg_add chkcfg_del);
 
-if (open (my $conf, "<", "/etc/sysv-rc-conf.conf")) {
-    while (<$conf>) {
-	next if /^\s*#/ or /^\s*$/;
-	my ($k, $v) = /^\s*(\S+)(?:\s+([^#]*?))?\s*(?:#.*)?$/ or die "malformed config line: $_";
-        if ($k =~ /^no-(.*)$/) {
-            $k = $1;
-            $v = 0;
+foreach my $conffile (grep { -s } (
+    "/usr/share/sysv-rc-conf/config",
+    "/etc/sysv-rc-conf.conf",
+    "$ENV{HOME}/.sysv-rc-confrc",
+)) {
+    if (open (my $conf, "<", $conffile)) {
+        while (<$conf>) {
+            next if /^\s*#/ or /^\s*$/;
+            my ($k, $v) = /^\s*(\S+)(?:\s+([^#]*?))?\s*(?:#.*)?$/ or die "malformed config line: $_";
+            if ($k =~ /^no-(.*)$/) {
+                $k = $1;
+                $v = 0;
+            }
+            $opts{$k} = $v ne '' ? $v : 1;
         }
-	$opts{$k} = $v ne '' ? $v : 1;
+        close $conf;
     }
-    close $conf;
 }
 
 GetOptions("cache=s"	=> \$opts{cache_dir},
@@ -151,7 +158,7 @@ GetOptions("cache=s"	=> \$opts{cache_dir},
            "add=s"      => \$opts{chkcfg_add},
            "del=s"      => \$opts{chkcfg_del},
 	   "order=s"	=> \$opts{order},
-	   "priority"	=> \$opts{priority},
+	   "priority|p"	=> \$opts{priority},
            "Purge"      => \$opts{purge_cache},
 	   "root=s"	=> \$opts{root},
 	   "show=s"	=> \$opts{show},
@@ -182,7 +189,7 @@ if (scalar (grep { defined $opts{$_} } @mutually_exclusive_options) > 1) {
     pod2usage(-msg => "Mutually exclusive options specified\n");
 }
 $opts{chkcfg_type} eq "sysv" or die "Only 'sysv' type services supported";
-
+$opts{pictograms} = ($ENV{LANG} =~ /\.UTF-8$/ ? 1 : 0) if $opts{pictograms};
 $opts{ui} //= 0 if $opts{purge_cache};
 $opts{ui} //= 1;
 
@@ -264,7 +271,7 @@ if ($opts{ui}) {
     $s[$current_screen]->focus();
 }
 
-ui_warning("$unsuitable_init") if defined $unsuitable_init;
+ui_warning("$unsuitable_init") if defined $unsuitable_init and $opts{warninit};
 
 if ($opts{ui}) {
     $cui->mainloop();
@@ -927,6 +934,10 @@ sub check_suitable_init
                "${OURNAME}'s controls will be ineffective for services with " .
                "service directories managed by runit.\n" .
 	       "Use update-service(8).";
+    } elsif ( -d "/run/openrc" ) {
+        return "openrc is runlevel manager;\n" .
+               "${OURNAME}'s controls will be ineffective.\n" .
+               "Use rc-update(8).";
     } else {
         return undef;
     }
@@ -1032,7 +1043,7 @@ sub split_services
                 $ddsn =~ /^(\d\d)(.+)$/;
                 if (exists $o_opts{n}) {
                     # Include the priority num on a pri sort
-                    push @services, $1.$2;
+                    push @services, "$1 $2";
                 }
                 else {
                     push @services, $2;
@@ -1734,7 +1745,7 @@ B<--order>.
 
 Show (default), or do not show, an interpretation of the current runlevel
 symlinks on the right hand side of the simple view. This note is truncated
-if the terminal is wide enough.
+if the terminal is not wide enough.
 
 =item B<--defdiff>, B<--no-defdiff>
 
@@ -1743,8 +1754,7 @@ current runlevel settings differ from LSB defaults.
 
 =item B<--pictograms>, B<--no-pictograms>
 
-Show (default), or do not show, unicode pictogram characters in the user
-interface.
+Show, or do not show, unicode pictogram characters in the user interface.
 
 =back
 
@@ -1899,8 +1909,30 @@ As per B<--verbose>.
 
 Always operate in read-only mode as per B<--RO>.
 
+=item B<pictograms> or B<no-pictograms>
+
+Whether to use unicode symbols.
+
+=item B<interpret> or B<no-interpret>
+
+Whether to show symlink status analysis on right hand side.
+
+=item B<no-warninit>
+
+Disable warnings about alternative init systems.
+
 =back
 
+=item F</usr/share/sysv-rc-conf/config>
+
+If present, processed before F</etc/sysv-rc-conf.conf>. This is a good place
+for downstream packagers to put distribution-specific defaults that may differ
+from built-in defaults.
+
+=item F<.sysv-rc-confrc> in user's home directory
+
+If present, processed after F</etc/sysv-rc-conf.conf>.
+
 =item F</var/lib/sysv-rc-conf/services>
 
 B<sysv-rc-conf> stores a cache of all the symlink information from 
